%global _hardened_build 1
%global debug_package %{nil}
%global srcname ejabberd


Name:           ejabberd
Version:        17.07
Release:        1%{?dist}

License:        GPLv2+
Summary:        A distributed, fault-tolerant Jabber/XMPP server
URL:            http://www.ejabberd.im/
VCS:            scm:git:https://github.com/processone/ejabberd.git
Source0:        https://github.com/processone/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
Source2:        ejabberd.logrotate

# Support for systemd
Source4:        ejabberd.service

# PAM support
Source9:        ejabberdctl.pam
Source11:       ejabberd.pam

# polkit support
Source12:       ejabberdctl.polkit.actions
Source13:       ejabberdctl.polkit.rules
# SELinux module
Source14:       ejabberd.te
Source15:       ejabberd.fc
Source16:       ejabberd.if


# Use ejabberd as an example for PAM service name (fedora/epel-specific)
Patch1: ejabberd-0001-Fix-PAM-service-example-name-to-match-actual-one.patch
# https://github.com/processone/ejabberd/issues/1850
Patch2: ejabberd-0002-Drop-post_hook_configure-from-rebar.config.patch
# Fedora-specific
Patch3: ejabberd-0003-Install-into-BINDIR-instead-of-SBINDIR.patch
# Fedora-specific
Patch4: ejabberd-0004-Enable-systemd-notification-if-available.patch


BuildRequires:  elixir >= 1.4.4
BuildRequires:  erlang-cache_tab >= 1.0.9
BuildRequires:  erlang-esip >= 1.0.13
BuildRequires:  erlang-ezlib >= 1.0.2
BuildRequires:  erlang-fast_tls >= 1.0.13
BuildRequires:  erlang-fast_xml >= 1.1.23
BuildRequires:  erlang-fast_yaml >= 1.0.10
BuildRequires:  erlang-iconv >= 1.0.5
BuildRequires:  erlang-jiffy >= 0.14.8
BuildRequires:  erlang-lager >= 3.4.2
BuildRequires:  erlang-luerl >= 0.2
BuildRequires:  erlang-meck >= 0.8.4
BuildRequires:  erlang-odbc
BuildRequires:  erlang-p1_mysql >= 1.0.3
BuildRequires:  erlang-p1_oauth2 >= 0.6.1
BuildRequires:  erlang-p1_pam >= 1.0.3
BuildRequires:  erlang-p1_pgsql >= 1.1.3
BuildRequires:  erlang-p1_utils >= 1.0.9
BuildRequires:  erlang-rebar
BuildRequires:  erlang-riak_client
BuildRequires:  erlang-sd_notify
BuildRequires:  erlang-stringprep >= 1.0.9
BuildRequires:  erlang-stun >= 1.0.12
BuildRequires:  erlang-xmpp >= 1.1.13
BuildRequires:  expat-devel >= 1.95
BuildRequires:  git
BuildRequires:  libyaml-devel >= 0.1.4
BuildRequires:  openssl-devel >= 1.0.0
BuildRequires:  pam-devel
BuildRequires:  selinux-policy-devel

BuildRequires:  autoconf
BuildRequires:  automake

# For creating user and group
Requires(pre):  shadow-utils

Requires(post): /usr/bin/openssl
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Provides: user(%{name})
Provides: group(%{name})

# From rebar
Requires:   elixir >= 1.1.0
# We install a logrotate.d file
Requires:   logrotate
# for /usr/bin/pkexec
Requires:   polkit
# for flock in ejabberdctl
Requires:   util-linux


%description
ejabberd is a Free and Open Source distributed fault-tolerant
Jabber/XMPP server. It is mostly written in Erlang, and runs on many
platforms (tested on Linux, FreeBSD, NetBSD, Solaris, Mac OS X and
Windows NT/2000/XP).


%package selinux
BuildArch: noarch

Summary: SELinux policy for ejabberd

Requires: selinux-policy
Requires: selinux-policy-targeted
Requires(post): /usr/sbin/selinuxenabled
Requires(post): /usr/sbin/semodule
Requires(posttrans): /usr/sbin/restorecon


%description selinux
This is the SELinux policy for ejabberd.


%prep
%autosetup -p1

# Upstream seems to import erlang-xmpp and erlang-fast_xml in a way that isn't compatible with them
# being system libraries. We need to patch the include statements to fix this.
# https://github.com/processone/ejabberd/pull/1446/
find . -name "*.hrl" | xargs sed -i \
    "s/include(\"fxml.hrl/include_lib(\"fast_xml\/include\/fxml.hrl/"
find . -name "*.erl" | xargs sed -i "s/include(\"jid.hrl/include_lib(\"xmpp\/include\/jid.hrl/"
find . -name "*.hrl" | xargs sed -i "s/include(\"ns.hrl/include_lib(\"xmpp\/include\/ns.hrl/"
find . -name "*.erl" | xargs sed -i "s/include(\"xmpp.hrl/include_lib(\"xmpp\/include\/xmpp.hrl/"
find . -name "*.hrl" | xargs sed -i \
    "s/include(\"xmpp_codec.hrl/include_lib(\"xmpp\/include\/xmpp_codec.hrl/"

# A few dependencies are configured to be found in the deps folder instead of in system libs
# https://github.com/processone/ejabberd/issues/1850
perl -p -i -e "s|deps/p1_utils/include|$(rpm -ql erlang-p1_utils | grep -E '/include$' )|g" rebar.config
perl -p -i -e "s|deps/fast_xml/include|$(rpm -ql erlang-fast_xml | grep -E '/include$' )|g" rebar.config
perl -p -i -e "s|deps/xmpp/include|$(rpm -ql erlang-xmpp | grep -E '/include$' )|g"   rebar.config

cp %{S:14} %{S:15} %{S:16} .


%build
autoreconf -ivf

%configure --enable-odbc --enable-mysql --enable-pgsql --enable-pam --enable-zlib --enable-iconv --enable-debug --enable-lager --libdir=%{_libdir}/erlang/lib/ --with-erlang=%{_libdir}/erlang/ --enable-system-deps --enable-stun

%{erlang_compile}

# Build the SELinux policy
make NAME=ejabberd -f /usr/share/selinux/devel/Makefile DISTRO=fedora%{fedora}


%install
%{erlang_install}

sed -e "s*{{rootdir}}*%{_prefix}*" \
    -e "s*{{installuser}}*%{name}*" \
    -e "s*{{bindir}}*%{_bindir}*" \
    -e "s*{{libdir}}*%{_erllibdir}*" \
    -e "s*{{sysconfdir}}*%{_sysconfdir}*" \
    -e "s*{{localstatedir}}*/var*" \
    -e "s*{{docdir}}*%{_datadir}/doc/%{name}*" \
    -e "s*{{erl}}*%{_erldir}/bin/erl*" \
    -e "s*{{epmd}}*%{_erllibdir}/bin/epmd*" ejabberdctl.template \
> ejabberdctl.example

install -d -m 0750 %{buildroot}%{_sysconfdir}/%{name}
install -D -p -m 0644 ejabberd.yml.example %{buildroot}%{_sysconfdir}/%{name}/ejabberd.yml
install -D -p -m 0644 ejabberdctl.cfg.example %{buildroot}%{_sysconfdir}/%{name}/ejabberdctl.cfg
install -D -p -m 0644 inetrc %{buildroot}%{_sysconfdir}/%{name}/inetrc

install -D -p -m 0755 ejabberdctl.example %{buildroot}%{_bindir}/ejabberdctl

install -d -m 0750 %{buildroot}/var/lib/ejabberd
install -d -m 0750 %{buildroot}/var/lock/ejabberdctl
install -d -m 0750 %{buildroot}/var/log/ejabberd

# fix example SSL certificate path to real one, which we created recently (see above)
%{__perl} -pi -e 's!/path/to/ssl.pem!/etc/ejabberd/ejabberd.pem!g' %{buildroot}/etc/ejabberd/ejabberd.yml

install -D -p -m 0755 tools/captcha.sh %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/bin/captcha.sh
# fix captcha path
%{__perl} -pi -e 's!/lib/ejabberd/priv/bin/captcha.sh!%{_libdir}/%{name}/priv/bin/captcha.sh!g' %{buildroot}/etc/ejabberd/ejabberd.yml

install -D -p -m 0644 %{S:9} %{buildroot}%{_sysconfdir}/pam.d/ejabberdctl
install -D -p -m 0644 %{S:11} %{buildroot}%{_sysconfdir}/pam.d/ejabberd

# install systemd entry
install -D -m 0644 -p %{S:4} %{buildroot}%{_unitdir}/%{name}.service

# install config for logrotate
install -D -p -m 0644  %{S:2} %{buildroot}%{_sysconfdir}/logrotate.d/ejabberd

# create room for additional files (such as SQL schemas)
install -d -m 0755 %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/
# install sql-scripts for creating db schemes for various RDBMS
install -p -m 0644 sql/lite.sql %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/
install -p -m 0644 sql/mssql.sql %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/
install -p -m 0644 sql/mysql.sql %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/
install -p -m 0644 sql/pg.sql %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/sql/

install -d -m 0755 %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/msgs/
install -p -m 0644 priv/msgs/*.msg %{buildroot}%{_erllibdir}/%{name}-%{version}/priv/msgs/

# Install polkit-related files
install -D -p -m 0644 %{S:12} %{buildroot}%{_datadir}/polkit-1/actions/ejabberdctl.policy
install -D -p -m 0644 %{S:13} %{buildroot}%{_datadir}/polkit-1/rules.d/51-ejabberdctl.rules

# Install the SELinux policy
install -d  %{buildroot}%{_datadir}/selinux/targeted
install -d %{buildroot}%{_datadir}/selinux/devel/include/apps

install -p -m 0644 ejabberd.pp %{buildroot}%{_datadir}/selinux/targeted/
install -p -m 0644 ejabberd.if %{buildroot}%{_datadir}/selinux/devel/include/apps/


%check
%{rebar_eunit}


%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
useradd -r -g %{name} -d %{_localstatedir}/lib/%{name} -s /sbin/nologin -M \
-c "ejabberd" %{name} 2>/dev/null || :


if [ $1 -gt 1 ]; then
    # we should backup DB in every upgrade
    if ejabberdctl status >/dev/null ; then
        # Use timestamp to make database restoring easier
        TIME=$(date +%%Y-%%m-%%dT%%H:%%M:%%S)
        BACKUPDIR=$(mktemp -d -p /var/tmp/ ejabberd-$TIME.XXXXXX)
        chown ejabberd:ejabberd $BACKUPDIR
        BACKUP=$BACKUPDIR/ejabberd-database
        ejabberdctl backup $BACKUP
        # Change ownership to root:root because ejabberd user might be
        # removed on package removal.
        chown -R root:root $BACKUPDIR
        chmod 700 $BACKUPDIR
        echo
        echo The ejabberd database has been backed up to $BACKUP.
        echo
    fi

    # fix cookie path (since ver. 2.1.0 cookie stored in /var/lib/ejabberd/spool
    # rather than in /var/lib/ejabberd
    if [ -f /var/lib/ejabberd/spool/.erlang.cookie ]; then
        cp -pu /var/lib/ejabberd/{spool/,}.erlang.cookie
        echo
        echo The ejabberd cookie file was moved again.
        echo Please delete old one from /var/lib/ejabberd/spool/.erlang.cookie
        echo
    fi
fi


%post
%systemd_post %{name}.service

# Create SSL certificate with default values if it doesn't exist
(cd /etc/ejabberd
if [ ! -f ejabberd.pem ]
then
    echo "Generating SSL certificate /etc/ejabberd/ejabberd.pem..."
    HOSTNAME=$(hostname -s 2>/dev/null || echo "localhost")
    DOMAINNAME=$(hostname -d 2>/dev/null || echo "localdomain")
    openssl req -new -x509 -days 365 -nodes -out ejabberd.pem \
                -keyout ejabberd.pem > /dev/null 2>&1 <<+++
.
.
.
$DOMAINNAME
$HOSTNAME
ejabberd
root@$HOSTNAME.$DOMAINNAME
+++
chown ejabberd:ejabberd ejabberd.pem
chmod 600 ejabberd.pem
fi)


%post selinux
if /usr/sbin/selinuxenabled ; then
/usr/sbin/semodule -i %{_datadir}/selinux/targeted/ejabberd.pp
fi


%posttrans selinux
/usr/sbin/restorecon -i -R /var/lib/ejabberd/
/usr/sbin/restorecon -i -R /var/log/ejabberd/


%preun
%systemd_preun %{name}.service


%preun selinux
if [ $1 -eq 0 ] && [ "$(/usr/sbin/semodule -l | grep ejabberd)" = "ejabberd" ]; then
    /usr/sbin/semodule -s targeted -r ejabberd &> /dev/null
fi


%postun
%systemd_postun_with_restart %{name}.service


%files
%license COPYING
%doc README README.md

%attr(750,ejabberd,ejabberd) %dir %{_sysconfdir}/ejabberd
%attr(640,ejabberd,ejabberd) %config(noreplace) %{_sysconfdir}/ejabberd/ejabberd.yml
%attr(640,ejabberd,ejabberd) %config(noreplace) %{_sysconfdir}/ejabberd/ejabberdctl.cfg
%attr(640,ejabberd,ejabberd) %config(noreplace) %{_sysconfdir}/ejabberd/inetrc

%{_unitdir}/%{name}.service

%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%config(noreplace) %{_sysconfdir}/pam.d/ejabberdctl
%{_datadir}/polkit-1/actions/ejabberdctl.policy
%{_datadir}/polkit-1/rules.d/51-ejabberdctl.rules
%{_bindir}/ejabberdctl

%dir %{_erllibdir}/%{name}-%{version}
%dir %{_erllibdir}/%{name}-%{version}/ebin
%dir %{_erllibdir}/%{name}-%{version}/include
%dir %{_erllibdir}/%{name}-%{version}/priv
%dir %{_erllibdir}/%{name}-%{version}/priv/bin
%dir %{_erllibdir}/%{name}-%{version}/priv/msgs
%dir %{_erllibdir}/%{name}-%{version}/priv/sql

%{_erllibdir}/%{name}-%{version}/ebin/*.app
%{_erllibdir}/%{name}-%{version}/ebin/*.beam
%{_erllibdir}/%{name}-%{version}/include/*.hrl
%{_erllibdir}/%{name}-%{version}/priv/bin/captcha.sh
%{_erllibdir}/%{name}-%{version}/priv/msgs/*.msg
%{_erllibdir}/%{name}-%{version}/priv/sql/*.sql

%attr(750,ejabberd,ejabberd) %dir /var/lib/ejabberd
%attr(750,ejabberd,ejabberd) %dir /var/log/ejabberd


%files selinux
%{_datadir}/selinux/devel/include/apps/ejabberd.if
%{_datadir}/selinux/targeted/ejabberd.pp


%changelog
* Sun Oct 22 2017 Randy Barlow <bowlofeggs@fedoraproject.org> - 17.07-1
- Update to 17.07 (#1427123).
- https://blog.process-one.net/ejabberd-17-07/
- Add an SELinux policy subpackage.

* Sat Sep 23 2017 Randy Barlow <bowlofeggs@fedoraproject.org> - 17.01-5
- Run ejabberd directly in the unit file so it gets the correct SELinux context (#1424823).
- Don't run ejabberdctl through polkit, as it doesn't play nice with the SELinux policy.

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 17.01-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 17.01-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Feb 19 2017 Randy Barlow <bowlofeggs@fedoraproject.org> - 17.01-2
- Stop shipping the unneeded /usr/lib/tmpfiles.d/ejabberd.conf (#1186674).
- Stop putting a folder in /var/lock since that's a tmpfs.

* Sun Feb 12 2017 Randy Barlow <bowlofeggs@fedoraproject.org> - 17.01-1
- Update to 17.01 (#1416391).
- https://blog.process-one.net/ejabberd-17-01/

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 16.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Dec 30 2016 Randy Barlow <bowlofeggs@fedoraproject.org> - 16.12-1
- Update to 16.12 (#1400097).
- Rebase two patches.
- Add new erlang-xmpp dependency.
- Use sed to fix include statements on fast_xml and xmpp so they can be
  found from the system.
- Run the test suite.

* Sun Dec 25 2016 Randy Barlow <bowlofeggs@fedoraproject.org> - 16.09-5
- Use auth_admin for all polkit default rules (#1094143).
- Drop unused BuildRequires on hevea and texlive-comment.
- Add a Requires on logrotate since we install a logrotate.d file.

* Thu Dec 01 2016 Randy Barlow <bowlofeggs@fedoraproject.org> - 16.09-4
- Drop the use of -set-cookie since it is unsafe.
- Configure the ejabberdctl script to set INSTALLUSER so it uses su to be ejabberd (#1163812).

* Sun Nov 27 2016 Randy Barlow <bowlofeggs@fedoraproject.org> - 16.09-3
- Use -set-cookie in ejabberdctl so root can attach to the node (#1163812).
- Mark ejabberdctl as executable.
- Dropped unnecessary gcc-g++ BuildRequires.

* Thu Nov 10 2016 Randy Barlow <bowlofeggs@fedoraproject.org> - 16.09-2
- Use the correct path for erl in ejabberdctl (#1393652).
- Drop NoNewPrivileges=true from the unit file (#1393587).

* Mon Oct 17 2016 Randy Barlow <randy@electronsweatshop.com> - 16.09-1
- Update to 16.09 (#1376238).

* Mon Oct 17 2016 Peter Lemenkov <lemenkov@gmail.com> - 16.08-3
- Fix FTBFS in Rawhide

* Thu Aug 18 2016 Peter Lemenkov <lemenkov@gmail.com> - 16.08-2
- Reenable systemd notification
- Drop outdated dependency - p1_xmlrpc
- Add missing dependency - erlang-odbc
- Rearrange patches

* Sun Aug 07 2016 Randy Barlow <randy@electronsweatshop.com> - 16.08-1
- Update to 16.08.
- Drop the R19 patch since it is included upstream now.

* Sat Jul 30 2016 Randy Barlow <randy@electronsweatshop.com> - 16.06.1-1
- Update to 16.01.1 (#1351186).
- Backport commit 0737958b to build on Erlang 19.
- Remove commented make edoc, since upstream no longer ships docs in this source.

* Wed Jul 06 2016 Jeremy Cline <jeremy@jcline.org> - 16.06-1
- Update to 16.06 (#1351186)

* Tue May 03 2016 Randy Barlow <rbarlow@redhat.coM> - 16.04-1
- Update to 16.04.
- Remove a commented patch.

* Sun Apr 24 2016 Randy Barlow <rbarlow@redhat.com> - 16.03-1
- Update to 16.03.
- Use the new Erlang auto-requires abilities.
- Remove some commented code.
- Fixed mixed spaces and tabs (used spaces).
- Fixed use of macro in changelog.
- Add the READMEs as docs.
- Remove dependencies on NIF and DRV since this package no longer ships C code.

* Fri Apr 15 2016 Randy Barlow <rbarlow@redhat.com> - 16.02-2
- Remove the filter_provides statement. It is no longer needed, and it is suspected to cause
  problems with ARM dependencies.
- Remove some unused commented patches.

* Sun Mar 06 2016 Randy Barlow <rbarlow@redhat.com> - 16.02-1
- Update to 16.02

* Sun Mar 06 2016 Randy Barlow <rbarlow@redhat.com> - 16.01-4
- Run ejabberdctl with bash when stopping in the unit file (#1314753).

* Sun Feb 28 2016 Randy Barlow <rbarlow@redhat.com> - 16.01-3
- Set permissions to 755 on ejabberdctl so the ejabberd user can start the daemon (#1312709).
- Drop the commented deps source, as it is not used.

* Tue Feb 16 2016 Randy Barlow <rbarlow@redhat.com> - 16.01-2
- Clean up the requirements, adding versions where they are known.

* Tue Feb 16 2016 Randy Barlow <rbarlow@redhat.com> - 16.01-1
- Raise the version to 16.01.

* Fri Feb 12 2016 Randy Barlow <rbarlow@redhat.com> - 15.11-1
- Raise the version to 15.11.

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 14.07-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Nov 14 2014 Dan Horák <dan[at]danny.cz> - 14.07-6
- increase stack size for hevea on ppc64* (#1164209)

* Fri Nov 14 2014 Dan Horák <dan[at]danny.cz> - 14.07-5
- hevea exists for all relevant arches, enables build on s390(x) and ppc64(le) (#1161098)

* Wed Nov 12 2014 Marcin Juszkiewicz <mjuszkiewicz@redhat.com> - 14.07-4
- add aarch64 support

* Tue Nov 04 2014 Peter Lemenkov <lemenkov@gmail.com> - 14.07-3
- Rebuild with Erlang 17.3.3

* Sun Aug 31 2014 Peter Lemenkov <lemenkov@gmail.com> - 14.07-2
- Temporarily disable external http support (--with-http)
- Temporarily disable systemd notify
- Add missing BuildRequires: git

* Sat Aug 30 2014 Peter Lemenkov <lemenkov@gmail.com> - 14.07-1
- Ver. 14.07
- Dropped support for EPEL5, EPEL6
- Dropped initial untested support for GSSAPI - nobody is interested in testing
  and further developing this
- Fixed https://bugzilla.redhat.com/1089475
- Fixed https://bugzilla.redhat.com/1117450

* Thu Aug 28 2014 Peter Lemenkov <lemenkov@gmail.com> - 2.1.13-10
- Rebuild with Erlang 17.2.1

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.13-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.13-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Oct 27 2013 Peter Lemenkov <lemenkov@gmail.com> - 2.1.13-7
- Fixed systemd service-file

* Sat Oct 26 2013 Peter Lemenkov <lemenkov@gmail.com> - 2.1.13-6
- Fix polkit again
- Add dependency on Erlang's driver version

* Fri Sep 27 2013 Peter Lemenkov <lemenkov@gmail.com> - 2.1.13-5
- Fix wrong polkit policy (rhbz #1009408)

* Sun Sep 15 2013 Peter Lemenkov <lemenkov@gmail.com> - 2.1.13-4
- Use polkit instead of usermode on modern systems
- Restore user/group provides

* Thu Sep 05 2013 Peter Lemenkov <lemenkov@gmail.com> - 2.1.13-3
- TEMPORARY disable hevea - it's broken in F19+
- Fix building with unversioned docdir
- Move away from fedora-usermgmt

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jun 29 2013 Peter Lemenkov <lemenkov@gmail.com> - 2.1.13-1
- Ver. 2.1.13
- Don't install or use /etc/sysconfig/ejabberd on systemd-enabled systems
- Build with PIE (if available)
- Re-generate configure scripts

* Fri Mar 15 2013 Peter Lemenkov <lemenkov@gmail.com> - 2.1.12-1
- Ver. 2.1.12

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.11-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Oct 28 2012 Peter Lemenkov <lemenkov@gmail.com> - 2.1.11-6
- Fixed rhbz #846856

* Mon Sep 10 2012 Peter Lemenkov <lemenkov@gmail.com> - 2.1.11-5
- Cherry-picked three new patches from upstream trunk

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.11-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Jul 15 2012 Peter Lemenkov <lemenkov@gmail.com> - 2.1.11-3
- Fixed rhbz #758601 (no /etc/pam.d/password-auth in EL5)

* Sun Jul 15 2012 Peter Lemenkov <lemenkov@gmail.com> - 2.1.11-2
- Updated mod_admin_extra to work with R15B (see rhbz #840039)
- Updated list of arches where we don't have hevea
- Dropped abandonded and not working modules

* Sun May 06 2012 Peter Lemenkov <lemenkov@gmail.com> - 2.1.11-1
- Ver. 2.1.11
- Fixed systemd installation

* Sun Jan 15 2012 Peter Lemenkov <lemenkov@gmail.com> - 2.1.10-3
- Fixed systemd unit file

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Dec 28 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.1.10-1
- Ver. 2.1.10
- Works with systemd (closes rhbz #767793)

* Sun Dec 18 2011 Dan Horák <dan[at]danny.cz> - 2.1.9-2
- pdf docs require hevea, they are not prebuilt

* Tue Nov 22 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.1.9-1
- Ver. 2.1.9
- Fix for CVE-2011-4320

* Mon Jul 11 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.1.8-3
- Fix for systemd (F15+ only, see rhbz #656581)

* Sat Jun 18 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.1.8-2
- Fix ejabberdctl again

* Fri Jun 03 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.1.8-1
- Ver. 2.1.8 (very urgent bugfix for 2.1.7)

* Wed Jun 01 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.1.7-1
- Ver. 2.1.7 (bugfixes and security)

* Wed Jun 01 2011 Paul Whalen <paul.whalen@senecac.on.ca> - 2.1.6-5
- Added arm to conditional to build without hevea.

* Thu Feb 24 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.1.6-4
- Updated @online@ patch

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Jan 25 2011 Martin Langhoff <martin@laptop.org> 2.1.6-2
- Apply rebased @online@ patch from OLPC - EJAB-1391

* Tue Dec 14 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.6-1
- Ver. 2.1.6 (Bugfix release)

* Thu Aug 26 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.5-6
- More patches from trunk
- Rebased patches

* Thu Aug 26 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.5-5
- Backported %%patch11 from upstream (fixes LDAP)

* Wed Aug 18 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.5-4
- Add accidentally forgotten changes to ejabberd.logrotate

* Wed Aug 18 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.5-3
- Fixed http-poll (BOSH)
- New version of GSSAPI patch (backported from upstream)
- Fixed logrotate rule

* Wed Aug  4 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.5-2
- Don't require dos2unix for building anymore

* Wed Aug  4 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.5-1
- Ver. 2.1.5
- OpenSSL >= 0.9.8
- Doc-file features.* dropped (just a part of guide.*)
- Dropped upstreamed patches
- Don't use autoreconf

* Fri Jul 16 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.4-3
- Fix for Erlang/OTP R14A
- Added BR: autoconf

* Fri Jun 18 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.4-2
- No hevea for EL-6
- No hevea for s390 and s390x

* Fri Jun  4 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.4-1
- Ver. 2.1.4
- Rebased patches

* Mon Mar 29 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.3-6
- File permissions for captcha.sh were fixed

* Thu Mar 18 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.3-5
- Init-script fixed

* Thu Mar 18 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.3-4
- Really fix issue with "File operation error: eacces".

* Thu Mar 18 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.3-3
- Relax access rights of /usr/sbin/ejabberdctl (from 0550 to 0755)
- Invoke symlinked consolehelper instead of /usr/sbin/ejabberdctl
  in init-script
- Fixed "File operation error: eacces" issue. See rhbz #564686.

* Thu Mar 18 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.3-2
- Init-script enhancements

* Fri Mar 12 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.3-1
- Ver. 2.1.3
- Patches rebased

* Fri Mar  5 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.2-4
- Fixed issue with {erorr,nxdomain}

* Tue Feb 16 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.2-3
- Do not try to backup DB on every fresh install
- Do not force copying old erlang cookie file
- Add missing release notes for ver. 2.1.2
- Require erlang-esasl for krb5 support
- No such %%configure option - --enable-debug
- Patches were rebased and renumbered
- Add new BR util-linux(-ng)

* Fri Jan 29 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.2-2
- Fixed BZ #559925 (EJAB-1173)
- Changed order of rpmbuild targets in this spec to more natural one.

* Mon Jan 18 2010 Peter Lemenkov <lemenkov@gmail.com> 2.1.2-1
- Ver. 2.1.2

* Thu Dec 24 2009 Peter Lemenkov <lemenkov@gmail.com> 2.1.1-1
- Ver. 2.1.1
- Dropped patches 9,11,12,13 (accepted upstream)

* Thu Dec 10 2009 Peter Lemenkov <lemenkov@gmail.com> 2.1.0-2
- DB backups are made on every upgrade/uninstall
- Fixed installation of captcha.sh example helper
- Added patches 9,10,11,12,13 from Debian's package

* Fri Nov 20 2009 Peter Lemenkov <lemenkov@gmail.com> 2.1.0-1
- Ver. 2.1.0
- Upstream no longer providing ChangeLog
- Dropped ejabberd-build.patch (upstreamed)
- Dropped ejabberd-captcha.patch (upstreamed)
- Dropped ejabberd-decrease_buffers_in_mod_proxy65.patch (upstreamed)
- Dropped ejabberd-dynamic_compile_loglevel.patch (upstreamed)
- Dropped ejabberd-turn_off_error_messages_in_mod_caps.patch (upstreamed)
- Docs reorganized and added ability to rebuild them if possible
- Added back ppc64 target
- SQL-scripts moved to %%{_datadir}/%%{name} from %%doc

* Thu Nov  5 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.5-10
- mod_ctlextra was updated from r873 to r1020
- Fix for BZ# 533021

* Wed Sep 16 2009 Tomas Mraz <tmraz@redhat.com> - 2.0.5-9
- Use password-auth common PAM configuration instead of system-auth

* Wed Sep  9 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.5-8
- Fixed possible issue in the config file for logrotate
- Fixed possible issue while creating dummy certificate
- Added patches #5,6,7,8 from Debian

* Thu Aug 27 2009 Tomas Mraz <tmraz@redhat.com> - 2.0.5-7
- rebuilt with new openssl

* Tue Aug 25 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.5-6
- Since now, we using only ejabberdctl in the init-script (bz# 502361)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Apr 21 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.5-3
- CAPTCHA is back - let's test it.

* Sat Apr  4 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.5-2
- Really disable CAPTCHA

* Fri Apr  3 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.5-1
- Ver. 2.0.5
- Temporarily disabled CAPTCHA support

* Sun Mar 15 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.4-2
- Support for CAPTCHA (XEP-0158)
- Updated mod_ctlextra.erl (fixed EJAB-789, EJAB-864)

* Sun Mar 15 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.4-1
- Ver. 2.0.4

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jan 26 2009 Peter Lemenkov <lemenkov@gmail.com> 2.0.3-1
- Ver. 2.0.3
- Merged some stuff from git://dev.laptop.org/users/martin/ejabberd-xs.git

* Fri Jan 16 2009 Tomas Mraz <tmraz@redhat.com> 2.0.2-4
- rebuild with new openssl

* Thu Oct  2 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.2-3
- Fixed broken ejabberdctl (BZ# 465196)

* Sat Aug 30 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.2-2
- Added missing Requires

* Fri Aug 29 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.2-1
- Ver. 2.0.2

* Sat Aug  9 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.2-0.3.beta1
- PAM support (BZ# 452803)

* Sat Aug  9 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.2-0.2.beta1
- Fix build with --fuzz=0

* Sat Aug  9 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.2-0.1.beta1
- Version 2.0.2-beta1
- Fixed BZ# 452326
- Fixed BZ# 227270

* Sun Jun 22 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.1-4
- Last minute fix (issue with shortnames/fqdn)

* Sun Jun 22 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.1-3
-Fixed BZ# 439583, 452326, 451554

* Thu May 29 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.1-2
- Fixed BZ# 439583

* Sat May 24 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.1-1
- Ver. 2.0.1
- Upstreamed patches dropped
- No longer uses versioned libdir (/usr/lib/ejabberd-x.x.x)
- Added sql-scripts in docs-directory

* Mon May  5 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.0-3
- Fix build against R11B-2

* Sat Feb 23 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.0-2
- Disable docs again for EPEL (we haven't hevea for EPEL)

* Sat Feb 23 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.0-1
- Version 2.0.0

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.0.0-0.4.rc1
- Autorebuild for GCC 4.3

* Wed Jan 23 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.0-0.3.rc1
- Really enabled some previously disabled modules

* Wed Jan 23 2008 Peter Lemenkov <lemenkov@gmail.com> 2.0.0-0.2.rc1
- Enabled some previously disabled modules

* Sat Jan 19 2008 Matej Cepl <mcepl@redhat.com> 2.0.0-0.1.rc1
- Upgrade to the current upsteram version.
- Make ejabberd.init LSB compliant (missing Provides: tag)

* Thu Dec 27 2007 Matej Cepl <mcepl@redhat.com> 2.0.0-0.beta1.mc.1
- Experimental build from the upstream betaversion.

* Tue Dec 11 2007 Matej Cepl <mcepl@redhat.com> 1.1.4-2.fc9
- rebuild against new ssl library.
- rebuild against the newest erlang (see Patch
- fix %%changelog

* Wed Sep  5 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.4-1
- Drop LDAP patch
- Update mod_ctlextra
- Update to 1.1.4

* Tue Sep  4 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-11
- Fix ejabberdctl wrapper script - #276071

* Wed Aug 22 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-10
- Re-exclude ppc64

* Wed Aug 22 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-9
- Fix license
- Don't exclude ppc64

* Wed Aug 22 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-8
- Bump & rebuild to build against latest erlang package.

* Tue Jul 31 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-7
- Bump release and rebuild due to Koji hiccups.

* Tue Jul 31 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-6
- Don't try building on PPC64 since hevea isn't available on PPC64.

* Tue Jul 31 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-5
- Sigh...

* Tue Jul 31 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-4
- Don't forget to add patch.

* Thu Jul 26 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-3
- Add ejabberdctl (#199873)
- Add patch to fix LDAP authentication. (#248268)
- Add a sleep in init script between stop/start when restarting.
- LSB compliance cleanups for init script. (#246917)
- Don't mention "reload" in the init script usage string. (#227254)

* Tue Jul 24 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-2
- Update mod_ctlextra

* Fri Feb  2 2007 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.3-1
- Update to 1.1.3

* Wed Oct 11 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.2-2
- Fix logrotate script (BZ#210366)

* Mon Aug 28 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-10
- Bump release and rebuild.

* Mon Jul 3 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-9
- Updated init script - should hopefully fix some problems with status & stop commands.

* Mon Jun 26 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-8
- Bump release to that tagging works on FC-5.

* Thu Jun 22 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-7
- Oops drop bad patch.

* Thu Jun 22 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-6
- Split documentation off to a subpackage.
- Own _libdir/ejabberd-version
- Mark %%{_sysconfdir}/logrotate.d/ejabberd as %%config

* Thu Jun  8 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-5
- Patch the makefile so that it adds a soname to shared libs.

* Fri May 26 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-4
- Modify AD modules not to check for group membership.

* Thu May 25 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-3
- Add some extra modules

* Wed May 24 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-2
- Munge Makefile.in a bit more...
- Change ownership/permissions - not *everything* needs to be owned by ejabberd

* Wed May 24 2006 Jeffrey C. Ollie <jeff@ocjtech.us> - 1.1.1-1
- First version for Fedora Extras
